@@ -910,8 +910,8 @@ void KatePluginSearchView::startSearch()
         if (m_projectPluginView) {
             projectName = m_projectPluginView->property ("projectName").toString();
             m_resultBaseDir = m_projectPluginView->property ("projectBaseDir").toString();
-            if (!m_resultBaseDir.endsWith("/"))
-                m_resultBaseDir += "/";
+            if (!m_resultBaseDir.endsWith('/'))
+                m_resultBaseDir += '/';
             QStringList projectFiles = m_projectPluginView->property ("projectFiles").toStringList();
             files = filterFiles(projectFiles);
         }
@@ -1564,9 +1564,15 @@ void KatePluginSearchView::resultTabChanged(int index)
         return;
     }
 
+    m_ui.searchCombo->blockSignals(true);
+    m_ui.matchCase->blockSignals(true);
+    m_ui.useRegExp->blockSignals(true);
     m_ui.searchCombo->lineEdit()->setText(m_ui.resultTabWidget->tabText(index));
     m_ui.matchCase->setChecked(res->regExp.caseSensitivity() == Qt::CaseSensitive);
     m_ui.useRegExp->setChecked(res->regExp.patternSyntax() != QRegExp::FixedString);
+    m_ui.searchCombo->blockSignals(false);
+    m_ui.matchCase->blockSignals(false);
+    m_ui.useRegExp->blockSignals(false);
 }
 
 
