@@ -65,6 +65,8 @@
 
 //END Includes
 
+static const qint64 FileSizeAboveToAskUserIfProceedWithOpen = 10 * 1024 * 1024; // 10MB should suffice
+
 KateViewManager::KateViewManager (QWidget *parentW, KateMainWindow *parent)
     : QSplitter  (parentW)
     , m_mainWindow(parent)
@@ -255,9 +257,28 @@ void KateViewManager::slotDocumentOpen ()
     KateDocumentInfo docInfo;
     docInfo.openedByUser = true;
 
-    KTextEditor::Document *lastID = 0;
-    for (KUrl::List::Iterator i = r.URLs.begin(); i != r.URLs.end(); ++i)
-      lastID = openUrl( *i, r.encoding, false, false, docInfo);
+    QString fileList;
+
+    foreach ( const KUrl &url, r.URLs )
+    {
+      qint64 size = QFile( url.toLocalFile() ).size();
+
+      if ( size > FileSizeAboveToAskUserIfProceedWithOpen )
+      {
+        fileList += QString("<li>%1 (%2MB)</li>").arg( url.fileName() ).arg( size / 1024 / 1024 );
+      }
+    }
+
+    if ( !fileList.isEmpty() )
+    {
+      QString text = i18n( "<p>You are attempting to open one or more large files:</p><ul>%1</ul><p>Do you want to proceed?</p><p><strong>Beware that kate may stop responding for some time when opening large files.</strong></p>", fileList );
+
+      int ret = KMessageBox::warningYesNo( this, text, i18n("Opening Large File"), KStandardGuiItem::cont(), KStandardGuiItem::stop() );
+      if ( ret == KMessageBox::No )
+        return;
+    }
+
+    KTextEditor::Document *lastID = openUrls(r.URLs, r.encoding, false, docInfo);
 
     if (lastID)
       activateView (lastID);
@@ -308,6 +329,22 @@ KTextEditor::Document *KateViewManager::openUrl (const KUrl &url,
   return doc;
 }
 
+KTextEditor::Document *KateViewManager::openUrls (const QList<KUrl> &urls,
+                                                  const QString& encoding,
+                                                  bool isTempFile,
+                                                  const KateDocumentInfo& docInfo)
+{
+  QList<KTextEditor::Document *> docs = KateDocManager::self()->openUrls(urls, encoding, isTempFile, docInfo);
+
+  foreach (const KTextEditor::Document *doc, docs) {
+    if (!doc->url().isEmpty()) {
+      m_mainWindow->fileOpenRecent->addUrl( doc->url() );
+    }
+  }
+
+  return docs.isEmpty() ? 0 : docs.last();
+}
+
 KTextEditor::View *KateViewManager::openUrlWithView (const KUrl &url, const QString& encoding)
 {
   KTextEditor::Document *doc = KateDocManager::self()->openUrl (url, encoding);
