@@ -81,6 +81,11 @@ class KateViewManager : public QSplitter
                                     bool isTempFile = false,
                                     const KateDocumentInfo& docInfo = KateDocumentInfo());
 
+    KTextEditor::Document *openUrls (const QList<KUrl> &url,
+                                     const QString& encoding,
+                                     bool isTempFile = false,
+                                     const KateDocumentInfo& docInfo = KateDocumentInfo());
+
     KTextEditor::View *openUrlWithView (const KUrl &url, const QString& encoding);
 
   public Q_SLOTS:
