@@ -287,6 +287,7 @@ KateCompletionConfigTab::KateCompletionConfigTab(QWidget *parent)
 
   connect(ui->chkAutoCompletionEnabled, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->gbWordCompletion, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+  connect(ui->gbKeywordCompletion, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(ui->minimalWordLength, SIGNAL(valueChanged(int)), this, SLOT(slotChanged()));
   connect(ui->removeTail, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
 
@@ -316,6 +317,7 @@ void KateCompletionConfigTab::apply ()
   KateViewConfig::global()->setWordCompletion (ui->gbWordCompletion->isChecked());
   KateViewConfig::global()->setWordCompletionMinimalWordLength (ui->minimalWordLength->value());
   KateViewConfig::global()->setWordCompletionRemoveTail (ui->removeTail->isChecked());
+  KateViewConfig::global()->setKeywordCompletion (ui->gbKeywordCompletion->isChecked());
   KateViewConfig::global()->configEnd ();
 }
 
@@ -323,6 +325,7 @@ void KateCompletionConfigTab::reload ()
 {
   ui->chkAutoCompletionEnabled->setChecked( KateViewConfig::global()->automaticCompletionInvocation () );
   ui->gbWordCompletion->setChecked( KateViewConfig::global()->wordCompletion () );
+  ui->gbKeywordCompletion->setChecked( KateViewConfig::global()->keywordCompletion () );
   ui->minimalWordLength->setValue (KateViewConfig::global()->wordCompletionMinimalWordLength ());
   ui->removeTail->setChecked (KateViewConfig::global()->wordCompletionRemoveTail ());
 }
@@ -797,6 +800,7 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
   connect(textareaUi->chkShowSpaces, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(textareaUi->chkShowIndentationLines, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(textareaUi->chkShowWholeBracketExpression, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+  connect(textareaUi->chkAnimateBracketMatching, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(textareaUi->chkDeveloperMode, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
 
   connect(bordersUi->chkIconBorder, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
@@ -810,6 +814,7 @@ KateViewDefaultsConfig::KateViewDefaultsConfig(QWidget *parent)
   connect(bordersUi->chkShowFoldingMarkers, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(bordersUi->rbSortBookmarksByPosition, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
   connect(bordersUi->rbSortBookmarksByCreation, SIGNAL(toggled(bool)), this, SLOT(slotChanged()));
+  connect(bordersUi->cmbShowScrollbars, SIGNAL(activated(int)), this, SLOT(slotChanged()));
 }
 
 KateViewDefaultsConfig::~KateViewDefaultsConfig()
@@ -841,10 +846,12 @@ void KateViewDefaultsConfig::apply ()
   KateViewConfig::global()->setScrollBarMiniMapWidth (bordersUi->spBoxMiniMapWidth->value());
   KateViewConfig::global()->setFoldingBar (bordersUi->chkShowFoldingMarkers->isChecked());
   KateViewConfig::global()->setLineModification(bordersUi->chkShowLineModification->isChecked());
+  KateViewConfig::global()->setShowScrollbars( bordersUi->cmbShowScrollbars->currentIndex() );
 
   KateViewConfig::global()->setBookmarkSort (bordersUi->rbSortBookmarksByPosition->isChecked()?0:1);
   KateRendererConfig::global()->setShowIndentationLines(textareaUi->chkShowIndentationLines->isChecked());
   KateRendererConfig::global()->setShowWholeBracketExpression(textareaUi->chkShowWholeBracketExpression->isChecked());
+  KateRendererConfig::global()->setAnimateBracketMatching(textareaUi->chkAnimateBracketMatching->isChecked());
 
   // warn user that he needs restart the application
   if (!textareaUi->chkDeveloperMode->isChecked() != KateDocumentConfig::global()->allowSimpleMode())
@@ -879,8 +886,10 @@ void KateViewDefaultsConfig::reload ()
   bordersUi->chkShowLineModification->setChecked(KateViewConfig::global()->lineModification());
   bordersUi->rbSortBookmarksByPosition->setChecked(KateViewConfig::global()->bookmarkSort()==0);
   bordersUi->rbSortBookmarksByCreation->setChecked(KateViewConfig::global()->bookmarkSort()==1);
+  bordersUi->cmbShowScrollbars->setCurrentIndex( KateViewConfig::global()->showScrollbars() );
   textareaUi->chkShowIndentationLines->setChecked(KateRendererConfig::global()->showIndentationLines());
   textareaUi->chkShowWholeBracketExpression->setChecked(KateRendererConfig::global()->showWholeBracketExpression());
+  textareaUi->chkAnimateBracketMatching->setChecked(KateRendererConfig::global()->animateBracketMatching());
   textareaUi->chkDeveloperMode->setChecked(!KateDocumentConfig::global()->allowSimpleMode());
 }
 
@@ -1527,6 +1536,8 @@ void KateModOnHdPrompt::slotDiff()
   // Start a KProcess that creates a diff
   m_proc = new KProcess( this );
   m_proc->setOutputChannelMode( KProcess::MergedChannels );
+  qDebug() << "diff" << QString(ui->chkIgnoreWhiteSpaces->isChecked() ? "-ub" : "-u")
+     << "-" <<  m_doc->url().toLocalFile();
   *m_proc << "diff" << QString(ui->chkIgnoreWhiteSpaces->isChecked() ? "-ub" : "-u")
      << "-" <<  m_doc->url().toLocalFile();
   connect( m_proc, SIGNAL(readyRead()), this, SLOT(slotDataAvailable()) );
@@ -1540,9 +1551,11 @@ void KateModOnHdPrompt::slotDiff()
   m_proc->start();
 
   QTextStream ts(m_proc);
-  int lastln = m_doc->lines();
-  for ( int l = 0; l < lastln; ++l )
+  int lastln = m_doc->lines() - 1;
+  for ( int l = 0; l < lastln; ++l ) {
     ts << m_doc->line( l ) << '\n';
+  }
+  ts << m_doc->line(lastln);
   ts.flush();
   m_proc->closeWriteChannel();
 }
@@ -1575,9 +1588,15 @@ void KateModOnHdPrompt::slotPDone()
 
   if ( m_diffFile->size() == 0 )
   {
-    KMessageBox::information( this,
-                              i18n("Besides white space changes, the files are identical."),
-                              i18n("Diff Output") );
+    if (ui->chkIgnoreWhiteSpaces->isChecked()) {
+      KMessageBox::information( this,
+                                i18n("The files are identical."),
+                                i18n("Diff Output") );
+    } else {
+      KMessageBox::information( this,
+                                i18n("Ignoring amount of white space changed, the files are identical."),
+                                i18n("Diff Output") );
+    }
     delete m_diffFile;
     m_diffFile = 0;
     return;
