@@ -548,7 +548,7 @@ function tryStatement(line)
                     // make sure it's not commented out
                     if (currentString[i] == result[2] && (i == 0 || currentString[i - 1] != '\\')) {
                         // also make sure that this is not a line like '#include "..."' <-- we don't want to indent here
-                        if (currentString.match(/^#include/)) {
+                        if (currentString.match(/^#include/) || currentString.match(/'use strict'/)) {
                             return indentation;
                         }
                         cursor = new Cursor(currentLine, i);
